@@ -73,6 +73,8 @@
 #define TITLE_DISPTIME  10000
 #define HILIST_DISPTIME 5000
 
+#define FIREWORKS_NUM 3
+
 CStringDisplay* CGameWidget::m_pStringDisp;
 
 CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
@@ -129,9 +131,9 @@ CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
       setUpHitArea( m_pfish[i], type );
     }
 
-    m_pfireworks[0] = new CFireWorks(SCREENW,SCREENH);
-    m_pfireworks[1] = new CFireWorks(SCREENW,SCREENH);
-    m_pfireworks[2] = new CFireWorks(SCREENW,SCREENH);
+    for(i = 0; i < FIREWORKS_NUM; ++i){
+      m_pfireworks[i] = new CFireWorks(SCREENW,SCREENH);
+    }
 
     //
     m_pstartBtn = new CButton(  m_pDisplay->GetStartBtnImages(), 
@@ -144,14 +146,24 @@ CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
 }
 CGameWidget::~CGameWidget()
 {
-    delete m_timer;
-    delete m_pixmap;
-    delete m_pScoreMng[0];
-    delete m_pScoreMng[1];
-    delete m_pHiScoreReg;
-    delete m_pStringDisp;
-    delete m_pstartBtn;
-    delete m_pDisplay;
+  int i;
+
+  delete m_timer;
+  delete m_pixmap;
+  delete m_pScoreMng[0];
+  delete m_pScoreMng[1];
+  for(i = 0; i < m_allfish; ++i){
+    delete  m_pfish[i];
+  }
+  for(i = 0; i < FIREWORKS_NUM; ++i){
+    delete m_pfireworks[i];
+  }
+  delete m_netObj;
+  
+  delete m_pHiScoreReg;
+  delete m_pStringDisp;
+  delete m_pstartBtn;
+  delete m_pDisplay;
 }
 
 
@@ -443,12 +455,10 @@ void CGameWidget::paint(void)
 
     case GAME_CLEAR:
 	// Clear Game
-	//int h,m,s;
-	//QColor black(0, 0, 0);
-	painter_pixmap.fillRect(0, 0, width(), height(), black);	
-	m_pfireworks[0]->dispFire(&painter_pixmap);
-	m_pfireworks[1]->dispFire(&painter_pixmap);
-	m_pfireworks[2]->dispFire(&painter_pixmap);
+	painter_pixmap.fillRect(0, 0, width(), height(), black);
+	for(int i = 0; i < FIREWORKS_NUM; ++i){
+	  m_pfireworks[i]->dispFire(&painter_pixmap);
+	}
 	m_stopwatch.getClearTime(&h, &m, &s);
 	m_pDisplay->drawClearTime( &painter_pixmap, h, m, s);
       
@@ -555,9 +565,9 @@ void CGameWidget::setGameOverMsg(QPainter *paint)
   QString numStr;
 
   numStr.setNum(FISH_NUM - m_freefish, 10);
-  str += numStr +" fishes, Let's try again !!";
+  str += numStr +" fish, Let's try again !!";
   paint->setPen( black );
-  paint->drawText( 150, 350, str);
+  paint->drawText( GAMEOVER_MSG_POSX, GAMEOVER_MSG_POSY, str);
 
 }
 //
